==> kubernetes-model-0.1.5-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeMountBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class VolumeMountBuilder extends VolumeMountFluent<VolumeMountBuilder> implements VisitableBuilder<VolumeMount,VolumeMountBuilder>{

     VolumeMountFluent<?> fluent;
public VolumeMountBuilder(){
    this(new VolumeMount());
}
public VolumeMountBuilder( VolumeMountFluent<?> fluent ){
    this(fluent, new VolumeMount());
}
public VolumeMountBuilder( VolumeMountFluent<?> fluent , VolumeMount instance ){
    this.fluent = fluent; fluent.withMountPath(instance.getMountPath()); fluent.withName(instance.getName()); fluent.withReadOnly(instance.getReadOnly()); 
}
public VolumeMountBuilder( VolumeMount instance ){
    this.fluent = this; this.withMountPath(instance.getMountPath()); this.withName(instance.getName()); this.withReadOnly(instance.getReadOnly()); 
}

public EditableVolumeMount build(){
    EditableVolumeMount buildable = new EditableVolumeMount(fluent.getMountPath(),fluent.getName(),fluent.isReadOnly());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.40-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeMountBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class VolumeMountBuilder extends VolumeMountFluentImpl<VolumeMountBuilder> implements VisitableBuilder<VolumeMount,VolumeMountBuilder>{

     VolumeMountFluent<?> fluent;
public VolumeMountBuilder(){
    this(new VolumeMount());
}
public VolumeMountBuilder( VolumeMountFluent<?> fluent ){
    this(fluent, new VolumeMount());
}
public VolumeMountBuilder( VolumeMountFluent<?> fluent , VolumeMount instance ){
    this.fluent = fluent; fluent.withMountPath(instance.getMountPath()); fluent.withName(instance.getName()); fluent.withReadOnly(instance.getReadOnly()); 
}
public VolumeMountBuilder( VolumeMount instance ){
    this.fluent = this; this.withMountPath(instance.getMountPath()); this.withName(instance.getName()); this.withReadOnly(instance.getReadOnly()); 
}

public EditableVolumeMount build(){
    EditableVolumeMount buildable = new EditableVolumeMount(fluent.getMountPath(),fluent.getName(),fluent.isReadOnly());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
VolumeMountBuilder that = (VolumeMountBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
